/* Copyright 1998-2011 Research Foundation State University of New York */

/* This file is part of QuB.                                            */

/* QuB is free software; you can redistribute it and/or modify          */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation, either version 3 of the License, or    */
/* (at your option) any later version.                                  */

/* QuB is distributed in the hope that it will be useful,               */
/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
/* GNU General Public License for more details.                         */

/* You should have received a copy of the GNU General Public License,   */
/* named LICENSE.txt, in the QuB program directory.  If not, see        */
/* <http://www.gnu.org/licenses/>.                                      */

#ifndef DUMBLUCK_H
#define DUMBLUCK_H

#include "qubfits.h"

// example fitter plugin
// does "tries" iterations,
// each iteration multiplies each curve param by 1.01

class QUB_DumbLuck : public IQUB_Fitter
{
public:
	QUB_DumbLuck();
	void __cdecl Free();
	IQUB_Evts * __cdecl Events();
	const char * __cdecl getName();
	int __cdecl getParamCount();
	const char * __cdecl getParamName(int ix);
	double __cdecl getParamVal(int ix);
	void __cdecl setParamVal(int ix, double val);
	int __cdecl Fit(IQUB_Curve* curve, QF_Data **data, int ndata);
	void __cdecl Stop(); // from another thread
	int __cdecl getIterations();
	double __cdecl getParamErr(int ix);
	double * __cdecl getCurve();
	const char * __cdecl getMessage(); // if directed by event
	QTR_Impl* __cdecl getState();
	void __cdecl updateState(QTR_Impl* state);

private:
	QUB_Evts events;
	QUB_Tree state;

	// your params here:
	int tries;
	
	IQUB_Curve* curve;
	QF_Data* data;
	vector<double> ff;
	int iter;
	string msg;
	bool stopRequested;
};

// make your own factory function with this signature,
// and register it in qubfits plugin.cpp
IQUB_Fitter* __stdcall CreateDumbLuck();


#endif
